=============
geopathfinder
=============


A package for creating, quering, and searching in data structures holding geo data sets


Description
===========

A longer description of your project goes here...


Note
====

This project has been set up using PyScaffold 2.5.11. For details and usage
information on PyScaffold see http://pyscaffold.readthedocs.org/.
